package Client;

import java.awt.EventQueue;

import javax.swing.JFrame;
import javax.swing.JTextField;
import javax.swing.JButton;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import javax.swing.SwingConstants;

import Logic.MainLogic;

import java.awt.Font;

public class MainClient {

	private JFrame frame;
	private JTextField mMainDisplay;
	
	private MainLogic mLogic;
	private String mPendingSymbol;
	private boolean mIsOutput;

	/**
	 * Launch the application.
	 */
	public static void main(String[] args) {
		EventQueue.invokeLater(new Runnable() {
			public void run() {
				try {
					MainClient window = new MainClient();
					window.frame.setVisible(true);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
		});
	}

	/**
	 * Create the application.
	 */
	public MainClient() {
		initialize();
		mLogic = new MainLogic();
		mPendingSymbol = "";
		mIsOutput = true;
		mMainDisplay.setText("0");
	}

	// When a number is pressed, go here
	private void OnNumberPressed( int tNumber )
	{
		int tCurrent = Integer.parseInt(mMainDisplay.getText());
		if( mIsOutput )
			mMainDisplay.setText(Integer.toString(tNumber));// At the start, or after an operation, we want to erase the whole number and start anew
		else
			mMainDisplay.setText(Integer.toString( (tCurrent * 10) + tNumber));
		mIsOutput = false;
	}
	
	// When a symbol is pressed, go here
	private void OnSymbolPressed( String tSymbol )
	{
		//** Some commands are immediate
		if( tSymbol.equals("?") )
		{
			// Quack like a duck or something.
			return;
		}
		else if( tSymbol.equals("C") )
		{
			// Clear the logic and display of number
			mLogic.ClearMemory();
			mPendingSymbol = "";
			mIsOutput = true;
			mMainDisplay.setText("0");
			return;
		}
		
		//** And some commands don't take effect until the next command happens
		int tCurrent = Integer.parseInt(mMainDisplay.getText());
		
		// This bock here demonstrates pretty much all of programming.  We here are the UI.  mLogic is our brain.  We need to get our brain to do something
		// The general syntax for this is "NameOfOtherThing.NameOfCommand( OptionalArguments );"
//		if( mPendingSymbol.equals("+") || mPendingSymbol.equals("") )
//			*******************
//		else if( mPendingSymbol.equals("-") )
//			*******************
//		else if( mPendingSymbol.equals("*") )
//			*******************
//		else if( mPendingSymbol.equals("/") )
//			*******************

		if( tSymbol.equals("=") )// equals is like "Finish your last thing and then we're done", but doesn't erase the screen to 0
			tSymbol = "";
				
		if( !mPendingSymbol.equals("") )
			mMainDisplay.setText(Integer.toString( mLogic.GetNumber() ));

		mIsOutput = true;
		mPendingSymbol = tSymbol;
	}
	
	/**
	 * Initialize the contents of the frame.
	 */
	//
	//
	//
	// If you touch anything below here you risk the entire project just failing to load with no error messages.  UI is finicky.
	//
	//
	// 
	private void initialize() {
		frame = new JFrame();
		frame.setBounds(100, 100, 485, 400);
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.getContentPane().setLayout(null);
		
		mMainDisplay = new JTextField();
		mMainDisplay.setFont(new Font("Tahoma", Font.PLAIN, 24));
		mMainDisplay.setHorizontalAlignment(SwingConstants.RIGHT);
		mMainDisplay.setText("0");
		mMainDisplay.setEditable(false);
		mMainDisplay.setBounds(10, 11, 450, 46);
		frame.getContentPane().add(mMainDisplay);
		mMainDisplay.setColumns(10);
		
		JButton mButton7 = new JButton("7");
		mButton7.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnNumberPressed(7);
			}
		});
		mButton7.setBounds(52, 101, 50, 50);
		frame.getContentPane().add(mButton7);
		
		JButton mButton8 = new JButton("8");
		mButton8.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnNumberPressed(8);
			}
		});
		mButton8.setBounds(112, 101, 50, 50);
		frame.getContentPane().add(mButton8);
		
		JButton mButton9 = new JButton("9");
		mButton9.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnNumberPressed(9);
			}
		});
		mButton9.setBounds(172, 101, 50, 50);
		frame.getContentPane().add(mButton9);
		
		JButton mButton4 = new JButton("4");
		mButton4.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnNumberPressed(4);
			}
		});
		mButton4.setBounds(52, 162, 50, 50);
		frame.getContentPane().add(mButton4);
		
		JButton mButton5 = new JButton("5");
		mButton5.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnNumberPressed(5);
			}
		});
		mButton5.setBounds(112, 162, 50, 50);
		frame.getContentPane().add(mButton5);
		
		JButton mButton6 = new JButton("6");
		mButton6.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnNumberPressed(6);
			}
		});
		mButton6.setBounds(172, 162, 50, 50);
		frame.getContentPane().add(mButton6);
		
		JButton mButton1 = new JButton("1");
		mButton1.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnNumberPressed(1);
			}
		});
		mButton1.setBounds(52, 223, 50, 50);
		frame.getContentPane().add(mButton1);
		
		JButton mButton2 = new JButton("2");
		mButton2.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnNumberPressed(2);
			}
		});
		mButton2.setBounds(112, 223, 50, 50);
		frame.getContentPane().add(mButton2);
		
		JButton mButton3 = new JButton("3");
		mButton3.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnNumberPressed(3);
			}
		});
		mButton3.setBounds(172, 223, 50, 50);
		frame.getContentPane().add(mButton3);
		
		JButton mButton0 = new JButton("0");
		mButton0.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnNumberPressed(0);
			}
		});
		mButton0.setBounds(112, 284, 50, 50);
		frame.getContentPane().add(mButton0);
		
		JButton mButtonC = new JButton("C");
		mButtonC.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnSymbolPressed("C");
			}
		});
		mButtonC.setBounds(281, 101, 50, 50);
		frame.getContentPane().add(mButtonC);
		
		JButton mButtonMystery = new JButton("?");
		mButtonMystery.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnSymbolPressed("?");
			}
		});
		mButtonMystery.setBounds(341, 101, 50, 50);
		frame.getContentPane().add(mButtonMystery);
		
		JButton mButtonMultiply = new JButton("*");
		mButtonMultiply.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnSymbolPressed("*");
			}
		});
		mButtonMultiply.setBounds(281, 162, 50, 50);
		frame.getContentPane().add(mButtonMultiply);
		
		JButton mButtonDivide = new JButton("/");
		mButtonDivide.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnSymbolPressed("/");
			}
		});
		mButtonDivide.setBounds(341, 162, 50, 50);
		frame.getContentPane().add(mButtonDivide);
		
		JButton mButtonAdd = new JButton("+");
		mButtonAdd.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnSymbolPressed("+");
			}
		});
		mButtonAdd.setBounds(281, 223, 50, 50);
		frame.getContentPane().add(mButtonAdd);
		
		JButton mButtonMinus = new JButton("-");
		mButtonMinus.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnSymbolPressed("-");
			}
		});
		mButtonMinus.setBounds(341, 223, 50, 50);
		frame.getContentPane().add(mButtonMinus);
		
		JButton mButtonEquals = new JButton("=");
		mButtonEquals.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				OnSymbolPressed("=");
			}
		});
		mButtonEquals.setBounds(310, 284, 50, 50);
		frame.getContentPane().add(mButtonEquals);
	}
}
